from django.db import models
from django import forms
from gmaps.widgets import GmapsSelectAutocomplete


class GmapsField(models.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = kwargs.pop("max_length", 250)
        self.plugin_options = kwargs.pop("plugin_options", {})
        self.select2_options = kwargs.pop("select2_options", {})
        super(GmapsField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        self.plugin_options['gmaps_field_name'] = self.name
        defaults = {
            'form_class': GmapsFormField,
            'plugin_options': self.plugin_options,
            'select2_options': self.select2_options,
        }
        defaults.update(kwargs)
        return super(GmapsField, self).formfield(**defaults)


class GmapsFormField(forms.CharField):
    def __init__(self, plugin_options={}, select2_options={}, *args, **kwargs):
        kwargs.update({'widget': GmapsSelectAutocomplete(
            plugin_options=plugin_options, select2_options=select2_options
        )})
        super(GmapsFormField, self).__init__(*args, **kwargs)


class GeotypeField(models.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = kwargs.pop("max_length", 250)
        super(GeotypeField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'form_class': GeotypeFormField
        }
        defaults.update(kwargs)
        return super(GeotypeField, self).formfield(**defaults)


class GeotypeFormField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs.update({'widget': forms.Select})
        super(GeotypeFormField, self).__init__(*args, **kwargs)

# Fix field for South
try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ["^gmaps\.fields\.GmapsField"])
    add_introspection_rules([], ["^gmaps\.fields\.GeotypeField"])
except:
    pass



from django import forms
from django.conf import settings
from django.utils.safestring import mark_safe


class GmapsSelectAutocomplete(forms.TextInput):
    def __init__(self, attrs=None, plugin_options={}, select2_options={}):
        super(GmapsSelectAutocomplete, self).__init__(attrs)
        self.plugin_options = plugin_options
        self.select2_options = select2_options

    def render(self, name, value, attrs=None):
        res = super(GmapsSelectAutocomplete, self).render(name, value, attrs)
        tmp_id = attrs['id'].replace(self.plugin_options['gmaps_field_name'], '')

        if 'geocode_field' in self.plugin_options:
            self.plugin_options['geocodeid'] = '{}{}'.format(tmp_id, self.plugin_options['geocode_field'])

        if 'type_field' in self.plugin_options:
            self.plugin_options['typeid'] = '{}{}'.format(tmp_id, self.plugin_options['type_field'])

        opts = ""
        if self.plugin_options:
            for k, v in self.plugin_options.items():
                if k not in ['geocode_field', 'type_field']:
                    opts += u' data-plugin_{}="{}"'.format(k, v)
        if self.select2_options:
            for k, v in self.select2_options.items():
                opts += u' data-select2_{}="{}"'.format(k, v)

        res = mark_safe(
            u"""
            {}
            <div class="gmaps-map-init" id="gmaps-map-init-{}" data-googleapikey="{}"{}></div>
            """.
            format(
                res,
                attrs['id'],
                settings.GMAPS_API_KEY,
                opts
            )
        )
        return res

    class Media:
        js = (
            'https://maps.googleapis.com/maps/api/js?v=3.14&key={}&sensor=false'.format(settings.GMAPS_API_KEY),
            settings.JQUERY_LIB,
            u'{}gmaps/{}/select2.min.js'.format(settings.STATIC_URL, settings.SELECT2_VERSION),
            u'{}gmaps/js/gmap.js'.format(settings.STATIC_URL),
            u'{}gmaps/js/gmaps__init.js'.format(settings.STATIC_URL),
        )
        css = {u"all": (
            u"{}gmaps/{}/select2.css".format(settings.STATIC_URL, settings.SELECT2_VERSION),
            u"{}gmaps/css/gmaps.css".format(settings.STATIC_URL),
        )}




from setuptools import setup, find_packages
import gmaps

setup(
    name='twentytab-gmaps',
    version=gmaps.__version__,
    description='A django widget with Select2 integration that uses google geocode api to search places and create maps with markers',
    author='20tab S.r.l.',
    author_email='info@20tab.com',
    url='https://github.com/20tab/twentytab-gmaps',
    license='MIT License',
    install_requires=[
        'Django >=1.6',
        'django-appconf>=0.6',
    ],
    packages=find_packages(),
    include_package_data=True,
    package_data={
        '': ['*.html', '*.css', '*.js', '*.gif', '*.png', ],
}
)
